"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const statuses = require("statuses");
function stringifyRequest(req) {
    const lines = [];
    lines.push(req.method + " " + req.url + " HTTP/" + req.httpVersion);
    for (let i = 0; i < req.rawHeaders.length; i = i + 2) {
        lines.push(req.rawHeaders[i] + ": " + req.rawHeaders[i + 1]);
    }
    lines.push("");
    if (req.method === "POST" && req.body && !req.url.startsWith("/auth")) {
        lines.push(JSON.stringify(req.body));
    }
    return lines.join("\n");
}
exports.stringifyRequest = stringifyRequest;
function stringifyResponse(res, requestUrl, result) {
    const lines = [];
    lines.push("HTTP/1.1 " + res.statusCode + " " + res.statusMessage);
    const headers = res.getHeaders();
    for (const header in headers) {
        lines.push(header + ": " + headers[header]);
    }
    if (result && !requestUrl.startsWith("/auth")) {
        if (result.toJSON) {
            result = result.toJSON();
        }
        lines.push(JSON.stringify(result));
    }
    return lines.join("\n");
}
exports.stringifyResponse = stringifyResponse;
function makeResponseHeaderServer(version) {
    return "Realm-Object-Server/" + version;
}
exports.makeResponseHeaderServer = makeResponseHeaderServer;
function makeResponse(statusCode, headers) {
    const lines = [];
    const statusMessage = statuses[statusCode];
    lines.push("HTTP/1.1 " + statusCode + " " + statusMessage);
    for (const header in headers) {
        lines.push(header + ": " + headers[header]);
    }
    lines.push("");
    return lines.join("\r\n") + "\r\n";
}
exports.makeResponse = makeResponse;
//# sourceMappingURL=httpUtil.js.map